#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-4.2.2/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-discover
version:              4.2.2
visibility:           public
id:                   tasty-discover-4.2.2-KlZQtB1WukOHDoKsIKYe4y
key:                  tasty-discover-4.2.2-KlZQtB1WukOHDoKsIKYe4y
license:              MIT
copyright:
    2016 Luke Murphy
    2020 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  bed76d8296a0a14113b6078b69a4e68c
exposed:              True
exposed-modules:
    Test.Tasty.Config Test.Tasty.Discover Test.Tasty.Generator

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-8.10.3/site-local/tasty-discover-4.2.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tasty-discover-4.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.3/tasty-discover-4.2.2
hs-libraries:         HStasty-discover-4.2.2-KlZQtB1WukOHDoKsIKYe4y
depends:
    Glob-0.10.1-CFokxAMD1xZ9YV531dp03P base-4.14.1.0 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

